@@ -12,7 +12,7 @@ def run():
 
     log_file = 'dummy_autoupdate_log.txt'
 
-    logging.basicConfig(level=logging.DEBUG, filename=log_file)
+    logging.basicConfig(level=logging.INFO, filename=log_file)
 
     qapp = QApplication([])
     logger = logging.getLogger(__name__)
@@ -25,6 +25,10 @@ def run():
     except FileNotFoundError:
         pass
 
+    logger.info(f'{"*" * 10}')
+    logger.info(f'Starting version {__version__}!')
+    logger.info(f'{"*" * 10}')
+
     return qapp.exec_()
 
 
