@@ -21,7 +21,7 @@ class QTextEditLogger(logging.Handler, QObject):
             logging.Formatter(
                 '%(asctime)s %(levelname)s %(module)s %(funcName)s %(message)s'))
         logging.getLogger().addHandler(self)
-        logging.getLogger().setLevel(logging.DEBUG)
+        # logging.getLogger().setLevel(logging.DEBUG)
 
     def emit(self, record):
         msg = self.format(record)
